from typing import Dict, Optional
from pydantic import BaseModel, EmailStr, Field


class User(BaseModel):
    username: str
    email: EmailStr
    password: str


class Token(BaseModel):
    datacenter: str
    token: str


class UserLoginSchema(BaseModel):
    username: str
    password: str

    class Config:
        schema_extra = {"example": {"username": "user", "password": "weakpassword"}}


class DataCenterSchema(BaseModel):
    name: str = Field(min_length=3, max_length=50)
    url: str
    active: bool = False
    weight: float = 1.0


class ResourcePoolSchema(BaseModel):
    rpname: str = Field(min_length=3, max_length=50)
    from_template: str = Field(default="")
    num_vms: int = Field(default=1)
    manual: Optional[Dict] = Field(
        default={
            "https://kappa1.fured.cloud.bme.hu": 0,
            "https://kappa2.fured.cloud.bme.hu": 0,
            "https://kappa3.fured.cloud.bme.hu": 0,
        },
        nullable=True,
    )
    key: str = Field(min_length=10, max_length=100)


class VMFromRPSchema(BaseModel):
    rpname: str = Field(min_length=3, max_length=50)
    key: str = Field(min_length=10, max_length=100)


class ResourceStat(BaseModel):
    datacenter_name: str
    mem_max: int
    mem_used: int
    cpu_usage: float
    cpu_core: int
    vm_count: int
